@@ -1,6 +1,6 @@
 /*
  * hotp.c - implementation of the OATH HOTP algorithm
- * Copyright (C) 2009-2023 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,10 +22,11 @@
 #include <config.h>
 
 #include "oath.h"
-#include "hotp.h"
-#include "aux.h"		/* _oath_strcmp_callback */
+#include "hotp.h"		/* _oath_hotp_generate2,
+				   _oath_strcmp_callback */
 
-#include <stdio.h>		/* For snprintf. */
+#include <stdio.h>		/* snprintf */
+#include <string.h>		/* strcmp */
 
 #include "gc.h"
 
@@ -256,3 +257,10 @@ oath_hotp_validate (const char *secret,
 				      window, strlen (otp),
 				      _oath_strcmp_callback, (void *) otp);
 }
+
+int
+_oath_strcmp_callback (void *handle, const char *test_otp)
+{
+  char *otp = handle;
+  return strcmp (otp, test_otp) == 0 ? 0 : 1;
+}
