@@ -1,6 +1,6 @@
 /*
  * tst_usersfile.c - self-tests for Liboath usersfile functions
- * Copyright (C) 2009-2023 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -136,8 +136,8 @@ main (void)
     }
   if (last_otp != 1260206742)
     {
-      printf ("oath_authenticate_usersfile timestamp %ld != 1260203142\n",
-	      last_otp);
+      printf ("oath_authenticate_usersfile timestamp %lu != 1260203142\n",
+	      (unsigned long) last_otp);
       return 1;
     }
 
