@@ -24,6 +24,7 @@
 #include <pskc/pskc.h>
 
 #include "internal.h"
+#include <stdlib.h>		/* free */
 #include <string.h>		/* strverscmp */
 #include <libxml/parser.h>	/* xmlInitParser */
 #include <libxml/catalog.h>	/* xmlLoadCatalog */
@@ -116,7 +117,6 @@ pskc_global_done (void)
       xmlSecShutdown ();
 #endif
       xmlCleanupParser ();
-      xmlMemoryDump ();
     }
 
   _pskc_init--;
