@@ -1,6 +1,6 @@
 /*
  * tst_accessors.c - self-tests for libpskc accessor functions
- * Copyright (C) 2012-2023 Simon Josefsson
+ * Copyright (C) 2012-2024 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -245,7 +245,7 @@ const char *pskc_all =
   "        <Test/>"
   "      </Policy>" "    </Key>" "  </KeyPackage>" "</KeyContainerX>";
 
-void
+static void
 my_log (const char *msg)
 {
   puts (msg);
