@@ -1,6 +1,6 @@
 /*
  * tst_basic.c - self-tests for libpskc basic functions
- * Copyright (C) 2012-2023 Simon Josefsson
+ * Copyright (C) 2012-2024 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -27,7 +27,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-void
+static void
 my_log (const char *msg)
 {
   if (msg == NULL)
@@ -41,7 +41,7 @@ int
 main (void)
 {
   pskc_rc rc;
-  int i;
+  unsigned i;
 
   /* Check version. */
 
@@ -70,6 +70,12 @@ main (void)
       return 1;
     }
 
+  if (pskc_check_version ("UNKNOWN"))
+    {
+      printf ("pskc_check_version (UNKNOWN) didn't fail?!\n");
+      return 1;
+    }
+
   if (PSKC_VERSION_NUMBER < 0x02060300 || PSKC_VERSION_NUMBER >= 0x03000000)
     {
       printf ("PSKC_VERSION_NUMBER out of range?!\n");
@@ -126,14 +132,14 @@ main (void)
       str = pskc_pinusagemode2str (i);
       if (str == NULL)
 	{
-	  printf ("pskc_pinusagemode2str(%d) == NULL\n", i);
+	  printf ("pskc_pinusagemode2str(%u) == NULL\n", i);
 	  return 1;
 	}
 
       m = pskc_str2pinusagemode (str);
       if (m != i)
 	{
-	  printf ("pskc_str2pinusagemode(%s/%d) = %d\n", str, i, m);
+	  printf ("pskc_str2pinusagemode(%s/%u) = %u\n", str, i, m);
 	  return 1;
 	}
     }
@@ -146,14 +152,14 @@ main (void)
       str = pskc_valueformat2str (i);
       if (str == NULL)
 	{
-	  printf ("pskc_valueformat2str(%d) == NULL\n", i);
+	  printf ("pskc_valueformat2str(%u) == NULL\n", i);
 	  return 1;
 	}
 
       m = pskc_str2valueformat (str);
       if (m != i)
 	{
-	  printf ("pskc_str2valueformat(%s/%d) = %d\n", str, i, m);
+	  printf ("pskc_str2valueformat(%s/%u) = %u\n", str, i, m);
 	  return 1;
 	}
     }
@@ -166,14 +172,14 @@ main (void)
       str = pskc_keyusage2str (i);
       if (str == NULL)
 	{
-	  printf ("pskc_keyusage2str(%d) == NULL\n", i);
+	  printf ("pskc_keyusage2str(%u) == NULL\n", i);
 	  return 1;
 	}
 
       m = pskc_str2keyusage (str);
       if (m != i)
 	{
-	  printf ("pskc_str2keyusage(%d/%s) = %d\n", i, str, m);
+	  printf ("pskc_str2keyusage(%u/%s) = %u\n", i, str, m);
 	  return 1;
 	}
     }
@@ -188,7 +194,7 @@ main (void)
 
     if (pskc_str2keyusage ("foobar") != PSKC_KEYUSAGE_UNKNOWN)
       {
-	printf ("pskc_str2keyusage (\"foobar\") == %d\n",
+	printf ("pskc_str2keyusage (\"foobar\") == %u\n",
 		pskc_str2keyusage ("foobar"));
 	return 1;
       }
